@@ -179,8 +179,8 @@ SP_Fox <- function(x = 1, Data, ...) {
   SP_args <- c(x = x, Data = Data, list(...))
   SP_args$start$n <- 1
   SP_args$fix_n <- TRUE
-
-  do.call(SP, SP_args)
+  
+  do.call2(SP, SP_args)
 }
 class(SP_Fox) <- "Assess"
 
@@ -211,8 +211,9 @@ SP_ <- function(x = 1, Data, AddInd = "B", state_space = FALSE, rescale = "mean1
 
   Ind <- lapply(AddInd, Assess_I_hist, Data = Data, x = x, yind = yind)
   I_hist <- vapply(Ind, getElement, numeric(ny), "I_hist")
+  if(is.null(I_hist) || all(is.na(I_hist))) stop("No indices found.", call. = FALSE)
+  
   I_sd <- vapply(Ind, getElement, numeric(ny), "I_sd")
-  if(is.null(I_hist)) stop("No indices found.")
   nsurvey <- ncol(I_hist)
 
   if(state_space) {
