@@ -160,9 +160,11 @@ cDD_ <- function(x = 1, Data, AddInd = "B", state_space = FALSE, SR = c("BH", "R
 
   Ind <- lapply(AddInd, Assess_I_hist, Data = Data, x = x, yind = yind)
   I_hist <- vapply(Ind, getElement, numeric(ny), "I_hist")
+  if(is.null(I_hist) || all(is.na(I_hist))) stop("No indices found.", call. = FALSE)
+  
   I_sd <- vapply(Ind, getElement, numeric(ny), "I_sd")
   I_units <- vapply(Ind, getElement, numeric(1), "I_units")
-  if(is.null(I_hist)) stop("No indices found.", call. = FALSE)
+  
   nsurvey <- ncol(I_hist)
   
   if(MW) {
